package App::ABAN::PRF::OpenSSL;
#ABSTRACT: Pseudo-random functions built with OpenSSL.
use strict;
use warnings;

require DynaLoader;
our @ISA = qw(DynaLoader);
__PACKAGE__->bootstrap;

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

App::ABAN::PRF::OpenSSL - Pseudo-random functions built with OpenSSL.

=head1 VERSION

version 0.010

=head1 DESCRIPTION

This module provides some pseudo-random functions (PRFs) that are built
with OpenSSL ciphers. The PRFs are used to generate seekable
pseudo-random data to fill disks with.

=head1 FUNCTIONS

Both of these take the same long list of arguments:

B<func>(I<block>, I<key>, I<nonce>, I<zeroblock>, I<offset>, I<size>, I<output>)

This is the same list of arguments as the Nettle versions; see
L<App::ABAN::PRF::Nettle> for details.

=over 4

=item B<chacha_prf>

This uses the ChaCha20 cipher directly as a PRF. The byte offset
is used as the counter.

=item B<aes256_prf>

This uses AES with a 256-bit key in counter mode (AES-256-CTR) as a PRF.
The byte offset is used as the counter.

=back

=head1 AUTHOR

Anthony DeRobertis <anthony@derobert.net>

=head1 COPYRIGHT AND LICENSE

Copyright (C)2019-2020 Customer Relationship Metrics.
Copyright (C)2019-2020 Anthony DeRobertis.
Web page modern style (C)2020 Ruben Albornoz.

This program is free software; you can redistribute it and/or modify it
under the terms of the Perl Artistic License or the GNU General Public
License as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

In addition, if you are distributing under the GPL, as a special
exception, the above copyright holders give permission to link the code
of this program with the OpenSSL Library (or with modified versions of
OpenSSL that use the same license as OpenSSL), and distribute linked
combinations including the two. You must obey the GNU General Public
License in all respects for all of the code used other than OpenSSL.

This exception applies to versions of OpenSSL under the traditional
(pre-3.0) OpenSSL licensing, versions under Apache License v2, and any
future license OpenSSL may be released under.

If you modify this program, you may extend this exception to your
version, but you are not obligated to do so. If you do not wish to do
so, delete this exception statement from your version.

=cut
