package App::ABAN::Util;
#ABSTRACT: ABAN internal C utilities.
use strict;
use warnings;

require DynaLoader;
require Exporter;
our @ISA = qw(DynaLoader Exporter);
our @EXPORT_OK = qw(get_blockdev_size);

__PACKAGE__->bootstrap;

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

App::ABAN::Util - ABAN internal C utilities.

=head1 VERSION

version 0.010

=head1 SYNOPSIS

    use App::ABAN::Util qw(get_blockdev_size);
    sysopen my $fh, '/dev/sda', O_RDONLY;      # prob. needs root
    my $size = get_blockdev_size(fileno($fh));

=head1 FUNCTIONS

All these functions are exportable.

=over 4

=item B<get_blockdev_size>(I<fileno>)

Call BLKGETSIZE64 on a block device, which should already be open. Pass
the file number (not file handle); i.e., pass C<fileno($fh)> as I<fileno>.

=back

=head1 AUTHOR

Anthony DeRobertis <anthony@derobert.net>

=head1 COPYRIGHT AND LICENSE

Copyright (C)2019-2020 Customer Relationship Metrics.
Copyright (C)2019-2020 Anthony DeRobertis.
Web page modern style (C)2020 Ruben Albornoz.

This program is free software; you can redistribute it and/or modify it
under the terms of the Perl Artistic License or the GNU General Public
License as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

In addition, if you are distributing under the GPL, as a special
exception, the above copyright holders give permission to link the code
of this program with the OpenSSL Library (or with modified versions of
OpenSSL that use the same license as OpenSSL), and distribute linked
combinations including the two. You must obey the GNU General Public
License in all respects for all of the code used other than OpenSSL.

This exception applies to versions of OpenSSL under the traditional
(pre-3.0) OpenSSL licensing, versions under Apache License v2, and any
future license OpenSSL may be released under.

If you modify this program, you may extend this exception to your
version, but you are not obligated to do so. If you do not wish to do
so, delete this exception statement from your version.

=cut
